#!/bin/csh
# Wrapper script for 'arg'.               Author: R.A. Jansen -- Jan 13 2005
# Replaces marker characters in a template script with strings from multiple
# input lists using 'arg'.
#
# Example: suppose there are 3 different marker characters within a template
# script, and three equal-length lists of replacement strings. Then:
#   narg <template> <list1> <marker1> <list2> <marker2> <list3> <marker3>
# will substitute each of the markers in turn.  Note that -m0 is assumed for
# the first list.

if ( "-h" == "$1" || "--help" == "$1" || $#argv < 3 ) then
    echo "narg  (wrapper around 'arg')            Author: R.A. Jansen -- Jan 13 2005"
    echo " "
    echo "Usage:  narg <template> <inputs1> <marker1> [inputs2 marker2 ...] > output"
    echo " "
    echo "where 'inputs1', 'inputs2', etc... are files with substitution strings for"
    echo "marker characters 'marker1', 'marker2', etc..., respectively.  Each of the"
    echo "inputs lists needs to have the same number of lines.   If only one pair of"
    echo "inputs list and corresponding marker is provided the result is the same as"
    echo "when running 'arg -m0 <inputs> <template> <marker>'. For more information,"
    echo "see the man-page of 'arg'."
    echo " "
    exit
endif

set tem="$1" ; shift
set nl=`awk '{print NR}' $tem | tail -1`
#echo "narg:  template='"$tem"' ($nl lines)"

set i = 1
set old="/tmp/tmpnarg.$i"
\cp $tem $old

while ( a == a )
    if ( "" != "$1" && "" != "$2" ) then
       @ i = $i + 1
       set lis="$1"
       set mrk="$2"
       shift ; shift
       set out="/tmp/tmpnarg.$i"

       if ( 2 < $i ) then
          #echo "$i :  arg -m$nl $lis $tem '$mrk' ..."
          arg -m$nl $lis $old $mrk > $out
       else
          #echo "$i :  arg -m0 $lis $tem '$mrk' ..."
          arg -m0 $lis $old $mrk > $out
       endif

       set old = $out
    else if ( "" != "$1" ) then
       echo "ERROR: Missing marker character #$i, or syntax error."
       break
    else
       cat $out 
       break
    endif
end

# Clean-up...
\rm -fr /tmp/tmpnarg.?
